Getting Started
===============

The stable version of ``aiapy`` is available through both PyPI via ``pip``,

.. code-block:: shell

   pip install aiapy

as well as through the `Miniconda distribution <https://docs.conda.io/en/latest/miniconda.html>`__ via ``conda-forge``,

.. code-block:: shell

   conda install -c conda-forge aiapy

You can also install the development version from GitLab,

.. code-block:: shell

   git clone https://gitlab.com/LMSAL_HUB/aia_hub/aiapy.git
   cd aiapy
   pip install -e ".[dev]"

If you will be developing ``aiapy``, please see the :ref:`dev-guide`.
